@@ -5,8 +5,8 @@
 #'
 #' PKNCA has been cross-validated with both Phoenix WinNonlin(R) and Pumas
 #' (click here for the
-#' \href{http://www.humanpredictions.com/wp-content/uploads/2020/01/ACOP_2019_T102_NCA_performance_evaluation_Yingbo_revised.pdf}{cross-validation
-#' article})
+#' [cross-validation
+#' article](http://www.humanpredictions.com/wp-content/uploads/2020/01/ACOP_2019_T102_NCA_performance_evaluation_Yingbo_revised.pdf))
 #'
 #' A common workflow would load data from a file or database into a
 #' data.frame then run the following code.
@@ -30,7 +30,7 @@
 #' }
 #' @docType package
 #' @name PKNCA
-NULL
+"_PACKAGE"
 
 # To work with the use of dplyr's pipe within the exclude function
 utils::globalVariables(".")
