@@ -1,5 +1,3 @@
-source("generate.data.R")
-
 test_that("PKNCAresults object creation", {
   minimal_result <- PKNCAresults(data.frame(a=1), data=list())
   expect_equal(minimal_result$columns$exclude, "exclude")
@@ -401,6 +399,21 @@ test_that("getGroups.PKNCAresults", {
   )
 })
 
+test_that("group_vars.PKNCAresult", {
+  o_conc_group <- PKNCAconc(as.data.frame(datasets::Theoph), conc~Time|Subject)
+  o_data_group <- PKNCAdata(o_conc_group, intervals = data.frame(start = 0, end = 1, cmax = TRUE))
+  suppressMessages(o_nca_group <- pk.nca(o_data_group))
+
+  expect_equal(dplyr::group_vars(o_nca_group), "Subject")
+
+  # Check that it works without groupings as expected [empty]
+  o_conc_nongroup <- PKNCAconc(as.data.frame(datasets::Theoph)[datasets::Theoph$Subject == 1,], conc~Time)
+  o_data_nogroup <- PKNCAdata(o_conc_nongroup, intervals = data.frame(start = 0, end = 1, cmax = TRUE))
+  suppressMessages(o_nca_nogroup <- pk.nca(o_data_nogroup))
+
+  expect_equal(dplyr::group_vars(o_nca_nogroup), character(0))
+})
+
 test_that("as.data.frame.PKNCAresults can filter for only requested parameters", {
   tmpconc <- generate.conc(2, 1, 0:24)
   tmpdose <- generate.dose(tmpconc)
